summaryrefslogtreecommitdiff
path: root/lib/snapshot.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/snapshot.php')
-rw-r--r--lib/snapshot.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/lib/snapshot.php b/lib/snapshot.php
index 4b05b502d..ede846e5b 100644
--- a/lib/snapshot.php
+++ b/lib/snapshot.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* A snapshot of site stats that can report itself to headquarters
*
@@ -20,14 +20,14 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Stats
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
- * @copyright 2009 Control Yourself, Inc.
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
+ * @copyright 2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -36,16 +36,16 @@ if (!defined('LACONICA')) {
*
* This class will collect statistics on the site and report them to
* a statistics server of the admin's choice. (Default is the big one
- * at laconi.ca.)
+ * at status.net.)
*
* It can either be called from a cron job, or run occasionally by the
* Web site.
*
* @category Stats
- * @package Laconica
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @package StatusNet
+ * @author Evan Prodromou <evan@status.net>
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*
*/
@@ -125,7 +125,7 @@ class Snapshot
// Some basic identification stuff
- $this->stats['version'] = LACONICA_VERSION;
+ $this->stats['version'] = STATUSNET_VERSION;
$this->stats['phpversion'] = phpversion();
$this->stats['name'] = common_config('site', 'name');
$this->stats['root'] = common_root_url();
@@ -181,7 +181,7 @@ class Snapshot
'header' => 'Content-type: '.
'application/x-www-form-urlencoded',
'content' => $postdata,
- 'user_agent' => 'Laconica/'.LACONICA_VERSION
+ 'user_agent' => 'StatusNet/'.STATUSNET_VERSION
)
);
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* A snapshot of site stats that can report itself to headquarters